========================
ProtGPT2 Fine-Tuning
========================

.. article-info::
    :avatar: img/book_icon.png
    :date: Nov 10, 2023
    :read-time: 6 min read
    :author: Zeeshan Siddiqui
    :class-container: sd-p-2 sd-outline-muted sd-rounded-1

On this page, we will show and explain the use of ProtGPT2. As well as document the BioLM API for fine-tuning, demonstrate no-code and code interfaces.

-----------
Description
-----------

ProtGPT2 is a language model that can be used for de novo protein design and engineering.

The model is capable of generating de novo protein sequences that maintain amino acid and disorder propensities akin to natural proteins but are evolutionarily distant from known protein space. Secondary structure prediction suggests 88% of its sequences are globular, similar to natural proteins. ProtGPT2 can quickly generate sequences on standard workstations or be fine-tuned for specific protein families, with applications in various scientific fields. It can generate de novo protein sequences that are evolutionarily distinct yet exhibit natural-like properties and stabilities. ProtGPT2 also explores uncharted areas of the protein space, potentially contributing to advancements in biomedical and environmental science applications

By applying state-of-the-art techniques from natural language processing, specifically generative Transformers, ProtGPT2 is an example of how advanced computational methods are being leveraged to push the boundaries of synthetic biology and protein engineering. *Ferruz et al., 2022*

ProtGPT2's ability to produce sequences quickly and its capacity to be fine-tuned for specific families of proteins, makes it a flexible and valuable tool in multiple cutting-edge scientific and engineering domains

--------------------------------------
API Usage: Finetune ProtGPT2 Generator
--------------------------------------

The endpoint to Finetune ProtGPT2 Generator: `https://biolm.ai/api/v1/finetune_run/ <https://api.biolm.ai/#5c9d7905-d411-4000-896a-80651828ac7a>`_

^^^^^^^^^^^^^^^
Making Requests
^^^^^^^^^^^^^^^

.. tab-set::

    .. tab-item:: Curl
        :sync: curl

        .. code:: shell

            curl --location 'https://biolm.ai/api/v1/finetune_run/' \
            --header "Authorization: Token $BIOLMAI_TOKEN" \
            --header 'Content-Type: application/json' \
            --data '{
            "pipeline": "finetune_protgpt2_generator",
            "input_json": {
                "max_train": 2000,
                "max_validate": 500,
                "train": ["EVQSGSTNYNPSLKSRVTISVDKSQFSLKLTSVTVADTATYYCARGRFGSSGYGMDVWGQGTTVSVSS", "EVQTLTLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARGERRYSSVFYFDYWGQGILVTVSS", "EVQHWINQAPGYYWSWIRQPPGKGLEWIGEINHDGSTNYNPSLKSRVTISVDTSKNQFSLNLTSLTAADTALYYCARDYGSSSWYYYYGMDVWGQGTTVTVSS", "EVQTLSLTCTVSGGSISSGGYYWSWIRQPAGKGLEWIGRIYYSGYTGYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARGGPCSGGDCNSPWGQGTLVTVSS", "EVQVSVSCKASGYTFTSYYMHWVRQAPGQGLEWMGIINPSGGSTSYAQKFQGWVTMTRDTSTSTVYMELSRLRSDDTAVYYCARGYNVVPDGYNIDYWGQGTLVTVSS", "EVQVSSPALVKPTQTLTLTCTFSGFSLSTSGVGVGWIRQPPGKALEWLALIYWDDDKRYSPSLKARVTVSVDRSKNQVVLTMTNMDPVDTATYYCAHRNDSGSYWTWMDVWGQGTTVTISS", "EVQVSGGSISSSSYYWSWIRQPPGKGLEWIGEINHSGSTSYNPSLKSRVSISVDTSKNQFTLKLSSVTAADTAVYYCARTLQLLVVVPNFYFDYWGQGTLVTVSS", "EVQISGRFTISGGSVKGRFTISGGSVKDQFKISAVSVKGRFTVSGGSIKGRVTVSGSFTIPGGSVKGRFTVSGKFTIPGGSVMGRFTISG", "EVQTDTSYYWSWIRQPPGKGLEWIGEIYHSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARSHCSGGSCYLTCDVSGASCRASLAFWGQGTLVTVSS", "EVQTLTLTCTVSGYSISSGYYWGWIRQPPGKGLEWIGSIYYRGSSTSYNPSLKSRVSISIDTSKNQFSLKLSSVTAADTAVYYCAREGSGYSSGAFDIWGSAYYYGMDVWGQGTTVTVSSS", "EVQVSSNSAAWNWIRQPPGKGLEWIGEMYHSSSSTTYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAIYYCAKGWESSWADYWGQGTLVTVAS", "EVQTLSLTCTVSGGSISSGGYYWSWIRQHPGKGLEWIGYIDYSGSTNYNPSLKSRVSISVDTSKNQFSLKLSSVTAADTALYYCARGRSGIAVFQHFDYWGQGTLVTVSS", "EVQFWSGPTLVKPTQTLTLTCTFSGFSLSTSGMRVSWIRQSPSRGLEWLALIDWDDNKYYYSSSVRGRFTISRDDSKNTLDLQMNSLRDEDTAVYYCAKGGFHSSGWFGYYGMDVWGQGTMVTVSS", "EVQTLSLTCTVSGGSISSSNYWWTWIRQPPGKGLEFIAVISTGGSSTIYKPAVKGRVTISRDTSKNQFSLRLTSVTAADTAFYYCTREGHCSHSAFDIWGRGTLVTVSS", "EVQTLTLTCAISGDSMTGGYGMHWVRQPPGKGLEWIGFIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARDRYIAAYFGMDVWGQGTTVTVSS", "EVQTIDSLRAEDMYYWSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDTSINQFSLKLTSVTAADTAVYFCARQGYGGDSWGQGTLVTVSS", "EVQKFQGRVTMTEDTSTDTAYMELSSLRSEDTAVYYCARAQDRWVIGDYWYFDLWGRGTLVSVSS", "EVQVSSASVKVSCKASGYTFTDNWIGWVRQAPGQGLEWVGWINPNTGNPTYAQGFTGRFVFSLDTSVSTAYLQISSLKAEDTAVYYCARGLGAVAGAFDYWGQGTLVTVSS", "EVQIDTAYQWSWIRQPPGKGLEWIGEINHSGSVKYNSSLKSRVTISTDKSKNQFSLKVNSVTAADTALYYCARGRHESGSYFYFDSWGQGTLVTVSS", "EVQTLTLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISIDTSKNQFSLKLSSVTAADTAVYYCARLYYDSSGVPNYGMDVWGQGTTVTVSS", "EVQTLSLTCTVSGGSISSSNWWSWVRQPPGKGLEWIGEIYYSGSTYYNPSLKSRVTISVDKSKNHFSLKLSSVTAADTAVYYCARGLSGIFGYSGYWGQGTLVTVSS", "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKRQFSLKLSSVTAADTAVYYCARSYAAYCSGGSCFSEFFDYWGQGTLVTVSS", "EVQTLTLTCTVSGGSISSGSYYWSWIRQPPGKGLEYIGSLYTGATIYYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYFCARGGFGSAMTPLNWFDPWGQGTMVTVSS", "EVQMELSCASVSSVTVSSQWSLTLTCTVSGFSITGYYWSWIRQPPGKGLEWIGEIYHSGSIKYNPSLKSRVTISIDTSRNQFSLKLSSVTAADTAVYFCARAQCGGSGCGGYSFDYWGQGTVVTVSS", "EVQTLTLTCTVSGGSISSYYWSWIRQPPGKGLEWIGYIYYSGSTYYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCARIGGYFFDYWGQGTLVTVSS", "EVQTLSLTCTVSGGSISSYYWSWIRQPPGKGLEWIGYIYYSGSTYYNPSLKSRITISVDTSKNQFSLKLSSVTAADTAVYYCARITTSSHYDYWGQGTLVTVSS", "EVQMELSCAASGFTFDDYAMHWVRQAPGKGLEWVAFISYDGSNKYYADSVKGRFTISRDNPKNSLYLQMSSLRVEDTAVYYCAKDWTRYCGKDTLDYWGQGTLVTVSS", "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISIDSSKNQFSLKLSSVTAADTAVYYCARSPTRVVAANGLNYWGQGTMVTVSS", "EVQSSGRFTISRDNAKPVTYYWSWIRQPAGKGLEWIGRIYTSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARGAYLRRFWSGYFGMDVWGQGTTVTVSS", "EVQTLTLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCVRQVGYCSAFDIWGQGTLVTVSS", "EVQVSGGSISSYYWSWIRQPPGKGLEWIGEINHSGSTSYNPSLKSRVTISVDTSKNQFSLKLTSVTAADTAVYYCARRRQQLRRAPLVWGGGGGSPSWGQGTPVTISCEASGYTFNTRDTHWVRQAPGKGLEGVGYWSSTIDHNLPSLRDYVENFRNQFSLSITSMSAEDTAIYFCARSCGGHYYYDSSGMDVWGQGTTVTVSS", "EVQVSGISWNWIRQPPGKGLEWIGSFNWDSEYSPSVKSRLTWSADTSKNQFSLQLNSVTVEDSAVYYCARYSSSITIFGVVVWGQGTTVSASS", "EVQMELISIGSSYYYYGMDVWGQGTLVTVSSTNYNPNSVNPTQTLTLTSTVYDYWGQGTTVTVSSTYYNPYSVNPTQTLTLTGTT", "EVQVSGGYYWSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDTSKNQFSLKLTSVTAADTAVYFCARGPIWTKYYYDSSGAFDIWGQGTMVTVSS", "EVQTLSLTCTVSGGSISSSSNYWGWIRQPPGKGLEWIGSIYHSGSANYNPSLKSRVTISIDRSRNQFSLKLSSVTAADTAVYYCARDGGYGSGAFDIWGQGTMVTVSS", "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARSGSWGSFDYWGQGTLVTVSS", "EVQTSLVKPTQTLTLTCTFSGFSLSTSGVGVGWIRQPPGKALEWLALIYWNDDKRYSPSLEGRVTISVDTSTNQVSLKLNSVTTADTAVYYCTRGVGGAGPYYDYWGQGTLVTVSS", "EVQVSSYTGSVKGRFTISCKGSGYSISSYAMHWVRQAPGKGLEWMGWISPDDSDASYAQRFQGRITMTTDTSVSTNTLSLQMNSLRPEDTAVYFCARADNSGVKFDPWGQGTLVTVSS", "EVQHSGTSLVKPTQTLTLTCTFSGFSLSTRGVGVGWIRQPPGKALEWLALIYWDDDKRYSPSLASRVTLSKDTSKNQVVLTMTNMDPVDTATYYCARPSTVTLLWNYGMDVWGQGTTVTVSS", "EVQTLTLTCAISGDSISSNSAAWNWIRQSPSRGLEWLGRTYYNGTDYADSVKSRITINVDNSTNTLSLQMNSLTAEDTAVYFCARERGDYFDYWGQGTLVTVSS", "EVQMHWVRQAPGKGLEWVSYISSSGSTIYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDSALYHCAKDRAMMVRGLLDYWGQGTLVTVSS", "EVQISGDTAMQVSVKGRFTISCTVSGGSISSHFWTWIRQPPGKGLEWIGYIYYSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARGVWGSGSSIWGQGTTVTVSS", "EVQTLSLTCTVSGGSISSFYWSWIRQPPGKGLEWIGYIYYSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARAWVRWLSQYYFDYWGQGTLVTVSS", "EVQTLSLTCTVSGGSISSYYWSWIRQPPGKGLEWIGYIYYSGSTNYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCARTYFWSGYTDVWGQGTTVTVSS", "EVQVNWVRQAPGRGLEWISYIYSDSNKYYADSVKGRFTISRDDSKTLANLQMNSLKTEDTAVYYCARDHRRILTGYMDWGQGTLVTVSS", "EVQMDPSLKSRVTISIDTSKNQFSLRLNSVTAADTAVYYCAGVVSCSGGSPPFDYWGQGTLVTVSS", "EVQASGYTLVKPTQTLTLTCTFSGFSLSTSGVGVGWIRQPPGKALEWLALIFWDDDKRYSPSLKSRLTISKDTSKNQVVLTMTNMDPVDTATYYCAHDSPARLINYFDDYWGQGTLVTVSS", "EVQTLTLTCTVSGGSISSSSYFWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTMSIDKSKNQFSLKLSSVTAADTAVYYCARGKRREWYFDLRRGFDYWGQGTLVTVSS", "EVQTLSLTCTVSGGSISSGGYSWSWIRQHPGKGLEWIGYIYYSGSTYYNPSLKSRVTISVDTSKSQFSLKLSSVTAADTAVYYCARDRAAGILVRAFDIWGQGTLVTVSS", "EVQTSLVKPTQTLTLTCTFSGFSLSTSGMCVSWIRQPPGKALEWLALIDWDDDKYYSTSLKSRVTISIDTSKNHFSLQMNSLRAEDTAVYYCARAHRQSRGGAFDIWGQGTTVTVSS", "EVQTSGYYWSWIRQPPGKGLEWIGEIYHSGSTNYNPSLKSRVTMSVDTSKNQFSLKLSSVTAADTAVYYCARVSYYDSSWPPSPFDYWGQGTLVTVSS", "EVQTLTLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYHSGSTYYNPSLKTRVTISVDTSKNQFSLKLSSVTAADTAVYHCARVASGAGTGHYYFDYWGQGTLVTVSS", "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARDSGYGEYWLDPTNYFDYWGQGTLVTVSS", "EVQTLTLTCTFSGFTFNNNHIHWVRQAPGKGLEWMGGIIPIFGTANYAQKFQGRVTITADTSVTTSYMELSSLRSDDTAVYYCARDDGSGTTWSDTSYWGQGTLVTVSS", "EVQMELSSLRSEETATENVCTAYGGSLRLSCAASGFTFSSTSMHWVRQAPGKGLEWVAVISGSGGSTYYADSVKGRFTISRDNSKNTLYLQMNSLKTEDTAVYYCARYSSGPGGYFAFDIWGQGTTVTVSS", "EVQTLSLTCTVYGVGVKDYGWSWIRQPPGKGLEWIGYIYYSGSTNYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCAREPQTGVVAAFFDYWGQGTLVTVSS", "EVQTLTLTCTVSGGSISSGGYYWSWIRQHPGKGLEWIGYIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARVCGGSCYRSSWFDPWGQGTLVTVSS", "EVQVSGGYYWSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDTSPEQFSLKLTSVTAADTAVYYCAGGGGYDPYDFWSGYYSEYWGQGTLVTVSS", "EVQSLSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDTPHLQLSLTCSVTDRAVYYCARAVYFSGSNFFDYWGQGTLVTVSS", "EVQVSSNTLVKPTQTLTLTCTFSGFSLSTSGMCVSWIRQPPGKALEWLALIYWDDDKRYSPSLKSRVTISVDTSKNQFSLQLNSVTPEDSAAYYCARDGGRWFDFWGQGTLVVVSS", "EVQKFQGRVTMTEDTSKNTAYMELSSLRSEDTAVYYCARDRDTATGGYYGMDVWGQGTTVTVSS", "EVQTLSLTCTVSGGSISSGGFYWSWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAIYYCARGLWYSSGYLRAFDIWGQGTTVTVSS", "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYNPSVYKSLNTFSTDDSKSELSLNSLTAADTAMYFCARLERWDYYDVWGQGTTVTVSS", "EVQSSGYYLRVTTSRGPVTYYWSWIRQPPGRGLEWIGETFSGATIYHPSAVKGRVTMSVDTSKNQFSLKLSSVTAADTAVYFCARDLPHSSSPVYFDHWGQGTLVTVSS", "EVQTDSYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCARGGYYDNAFAWWFDLWGQGTLVTVSS", "EVQTLTLTCTVSGGSISSGGYYWNWIRQHPGKGLEWIGYIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARDRRGSSSHNWYLYDHWGQGTLVTVSS", "EVQTLSLTCTISGGSISSYYWSWIRQPPGKGLEWIGYIYYSGSTYYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCARVIVVGIPRAYDVWGQGTLVTVSS", "EVQISGDTAVYYWSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDKSRNSLSLKLSSVTAADTAVYFCARIRAPEAGGAWGTHDYWGQGTLVTVSS", "EVQVSGGSISSTSPMCVRQPPGDSLRLSCAASGFTFSSYAMSWVRQAPGKGLEWISRIKSSSSYTNYADSVKGRFTISRDDAKNSVYLQMDSLRADDTAVYYCARSLGYSSSWYFDLWGKGTTVTVSS", "EVQTLVTVSSPSWIRQPPGKALEWLAIDYSGDKYYSPSLKSRVTISVDTPNNQFSLKLTSVTAADTAVYHCARLRSRTLSSGPPFDYWGQGALVTVSP", "EVQIDYWYFDLWGQGTLVTVSSTELDTAMYYYGLGYAMKDFWQRTKVTVSSTTVTVSSTTATVSSTTTTVDTATYYVDVWGQGTLVTVSSTAWDTAVYHSGSTNFNPSLWGQGALVTVSSTSWTTNYYIDAWGQGTLVTVSSTDWDTALYYYDSSGTYYFDYWGQATLVTVSSTTWSTAYYYDGTSTSTLYP", "EVQTLTLTCTVSGGSISSGGYYWSWIRQHPGKGLEWIGYIYYSGSTYYNPSLKSRATISVDTSKNQFSLKLSSVTAADTAVYHCATLKGTALGWFDPWGQGTLVTVSS", "EVQVDTSNILFICGGAFAGLERIVSRRLGQGSIGFGASVGAKNTLESRHKGQSTLQLQETDVYGMVSDIVGMEDLLKFGLIPELVARLSTLVPMNSLSREALDVILLDTCRESFSQNQVELGVRLSVTPEAQDYLVRQSFDPAFGARPLRRAMQIYIEDPLSRAILSGEFAAEDTVVLRAEGDGLTFAPSA", "EVQVSSMTLVKPTQTLTLTCTFSGFPLSTYGIAWIRQPPGKALEWIGSIYHSGSTYYNPALKNRLTISKDTSKNQVVLTMTNMDPVDTATYYCAARPMLRRDAFDIWGQGTMVTVAS", "EVQTLTLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYYFGSTSYNPSLKSRVTISIDTSKNQFSLKLSSVTAADTAVYYCARAGSSSYSFGGQQLSNYFDVDVWGQGTTVTVSS", "EVQVSSMTAAWNDDTAYMELSCAASGFTFSSYWMHWVRQAPGKGLEWVAVISTGDSDTYIQSLQSRLTISKDTSKNQVVLTMTNMDPEDTAVYYCARHPHDENSGVGGVWGQGTLVTISS", "EVQTLSLTCTVSGGSISSYYWSWIRQPPGKGLEWIGSIYYSGSTNYNPSLKSRVTISVDKSKSQLNLKLSSVTAADTAVYFCARTASIFGVVKLLVPAALGFDYWGQGTLVTVSS", "EVQISGYYWSWIRQPNWMDVWGKGTTVTVSSASVKDYYWITIFGQGTMVTVSSTSVTGYSGSTFYSGATVTVSSTSVTVTSTYNYWGPYYSSTTVTVSSVSVTVSSTSAYYYGSYSSYTGSSYYNYGYRNWWGSGSNYWYSGYSSYYYSGSSSGYFYGYYSYYYGGYSSSRYYYYYG", "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAIYHCARHLGVSLAFDIWGRGTMVTVSS", "EVQTLSLTCTVSGGSISSYYWSWIRQPPGKGLEWIGYIYYSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARDPIAVVPTTGTFDYWGQGTLVTVSS", "EVQASGWIRQPPGKGLEWIGSISYSGSTYYNPSLKSRVTISVDKSKAQFSLKLNSVTAADTAVYYCARGVDWDFDFWGQGTLVIVSS", "EVQTSKNQVVLTMTNMDPSLKSCAASGPTLYLQMNSLTAVDTAMYYCARRFDVWGQGTLVSYKYSDAFDIWGQGTMVTVSS", "EVQVSGGNYYYWSWIRQPPGKALEWLALIYWDDDKYYSPSLKSRLTITKDTSKNQVVLTMTSLTAADTAVYYSARDWYGLEGIRGWLDPWGQGTLVTVSS", "EVQTLSLTCTVSGGSISSYYWAWIRQPPGRGLEWIGYIYYSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARLWGATMIVVGFDSWGQGTLVTVSS"],
                "validation": ["EVQTLTLTCTVSGGSISSYYWSWIRQPPGKGLEWIGYIYYSGSTNYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCARHSIAASGSYCHFDYWGQGTLVTVSS", "EVQTLTLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISADKSKNTLYLQMNSLRAEDTAVYHCARDPTTGVTVAVFDYWGQGTLVTVSS", "EVQISGISWVRQPSLKSREEVSCKVSSNYSGSTHYWTWIRQPPGKALEWIGYIYYSGSTYYNPSLESRVSISVDTSKNQFSLKLSSVTAADTAVYYCARRSLMPYFQHWGQGILVTVSS", "EVQVSSASVKVSCKASGYTFTSYAMHWVRQAPGQGLEWMGWINPSANTGYAQKFQGRVTMTRDTSISTAYMELSRLRSDDTAVYYCARLPIWEHYYYFDYWGQGTLVTVSS", "EVQVSSDIWGQGTLVTVSSKDTSKNQFSLKLSSVTAADTAVYYCARAPRLGSDYWGQGTLVIVSSKVTSRSQFYFSVSASGGSAYGQSGYDAFDIWGQGNLVTVSSKGGSGGQFSLQLNSVTAADTAIYFCARSITIFGSTFFGMDVWGQGTLVTVSA", "EVQTLSLTCTVSGGSISSNEWMNWVRQVPGKGLEWIGFVDPSDSTRYSPSFKSRLTMSLDTSVSTAYLQWRSLKASDTAMYYCARTRGMVRGIYAGDCGLYYFGYWGQGTLVTVSS", "EVQVSGGKDTSKNQFSLKASCAASGFTFSRFAMTWIRQSPGQGLEWIGRIDYSGSEKYYSDSVKTRLAISKDNFKNQVSLRLNSVTAADTGTYYCARTLVTVSAPLKFHDAFDIWGRGTLVTVSS", "EVQVSSPALVKPTQTLTLTCTFSGFSLSTNGVGVGWIRQPPGKALEWLALIYWDDDKRYSPSLRSHVSISKDTSKNQVVLTMTNMDPVDTATYYCAHVRTIFGVVWFGQGELVTVSS", "EVQAPGHISSGGYYWSWIRQPPGKGLEWIGEIYHSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARGRGDYDFWSGYLLDYWGQGTLVTVSS", "EVQTLSLTCTVSGGSVSSGSYYWSWIRQPPGKGLQWIGYIYYSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARETAVAGFDDCWGQGTLVTVSS", "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVSISIDKSKNQFSLKLSSVTPADTAVYYCARQSGYGGGVDVWGQGTTVTVSS", "EVQTSTAYMYWVRQAPGPGMEWVSGIGGAGATQHYADSVKGRFTISRDNSKNTVYLQMNSLKTEDTAVYYCAKDWRDFDYWGQGTLVTVSS", "EVQVSGSVKGRFTISRDYADSTYYYGYNPSLKSRVTISVDTSKNQFSLQSRSVTASDTAVYYCARATGDYWGQGTLVTVSS", "EVQDSDDTVYAEVKKPRPTKASVYTSTAYTQTLTLTCAVYSGSFSYYWGWIRQSPGKGLEWIGSAKSTSGNTNYNPSLKSRVTISVDTSKNQFSLKVRSVTAADTAMYYCARGRYSGGDAFDIWGQGTMVTVSS", "EVQTLSLTCTVSGGSISSSSYSWSWIRQPPGKGLEWIGYIYYSGSTYYNPSLKSRVTISVDQSKNQFSLKLSSVTAADTAVYYCATPPDYWGQGTLVTVSS", "EVQVSGGSFSGYYWSWIRQPPGKGLEWIGSIHYSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARGRCVVGGGIEFGMDVWGQGTTVTVSS", "EVQMPPISDSRVTIGVKVSRTTYYWSWVRQPPGKGLEWIGEINHDGSANYNPSFNPSLKSRLTIARDNAVTAYMELTSLTAADTGTYYCARRALGGSFDIWGQGTMVTVSS", "EVQMELSCLGLTSHWGLGQGYSMNWVRQAPGKGLEWVAVISYDGSNTKFADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCVKGDIVVVAAAWGALDFDYWGQGTLVTVSS", "EVQISGYTGSVKGRFTISKDTSKNQFSLKLSSVTAADTAVYYCARYYDGFDYVWGSYYWGQGTLVTVSS", "EVQTLSLTCTVSGGSISSYYWSWIRQPPGKGLEWIGYVYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYHCARDYDTATSRCYWGPGTLVTVSS", "EVQTSGMELTELSQTLSLTCMVQGTSLRSKYWSWVRQAPGKGLEWIGEINHSGSTNYNPKLQARLTISIDTSKNQFSLRLTSVTAADTAVYYCAHVRYYDNWNPDYFDYWGQGTLVTVSS", "EVQTLTLTCAISGDSMTGGYGMHWVRQPPGKGLEWIGFIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARDRYIAAYFGMDVWGQGTTVTVSS", "EVQVSGGSISSSSYYWSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARDVGYSSPDAFDIWGQGTMVTVSS", "EVQISGMELKFQGRVTIMPTANVSGTNYAQSLETLSLTCTVSGGSISSGGYYWSWIRQPAGKGLEWIGYIYTSGTTNYNPSLKSRLTISVDMSKNQFSLKLSSVTAADTAVYFCARGKYHSSYGMDVWGQGTTVTVSS", "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARSTFDYSSDFWGQGTLVTVSS", "EVQTLTLTCTVSGDSVSSYWNWIRQSPGTGLEWIGRIYTSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARSGYMDYYDSSGYFYWNWFDPWGQGTLVTVSS", "EVQVRGSQLELSSLSSMELSWYYYYMDVWGSGPTLVKPTQTLTLTCTFSGFSLSTSGMCVTWVRQARGQALEWLARIGDDDKYYSTSLKTRLTISKDTSKNQVVLTMTNMDPVDTATYYCARGLEWGFDYWGQGTLVTVSS", "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARHSIAARSQRSHYWGQGTLVTVSS", "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSYYYSGSTYYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYSARDSSISSMDVWGQGTVVTVSS", "EVQMRGPGLVKPTQTLTLTCTFSGFSLSTSGMCVSWIRQPPGKALEWLAIIYWDDDKFYSTSLKTRLTITKDTSKNQVVLTMTNMDPVDTATYYCARLVRYYDILTGRFDPWGQGTLVTVSS", "EVQTLSLTCSFSGSGFTFHWVRQAPGKGLEWVAVISYDGSNKYYADSVKGRFTISRDNSKNTLYLQMTSLRAEDTAVYYCARDPVGGYPVHYYYGMDVWGQGTTVTVSS", "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARDPMGTTSGGSIVVTIFGVVVPSVSVSP", "EVQMELSCAASGFTFSDYGMHWVRQAPGKGLEWVAVISYDGSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRDEDTAVYYCATDYQGDYSIDYWGQGTLVTVSS", "EVQVSGGYYWSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCASGSSYSGFDSYYDYWGQGTLVTVSS", "EVQTVSCKGSGYSFTAYINWVRQAPGQGLEWISRIDSSSTNTNYADSVKGRFTISRDNAKNTLFLQMNSLRAEDTAVYYCARGEGYWGQGTLVTVSS"],
                "epochs": 1
            }
            }'

    .. tab-item:: Python Requests
        :sync: python

        .. code:: python

            import requests
            import json

            url = "https://biolm.ai/api/v1/finetune_run/"

            payload = json.dumps({
            "pipeline": "finetune_protgpt2_generator",
            "input_json": {
                "max_train": 2000,
                "max_validate": 500,
                "train": [
                "EVQSGSTNYNPSLKSRVTISVDKSQFSLKLTSVTVADTATYYCARGRFGSSGYGMDVWGQGTTVSVSS",
                "EVQTLTLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARGERRYSSVFYFDYWGQGILVTVSS",
                "EVQHWINQAPGYYWSWIRQPPGKGLEWIGEINHDGSTNYNPSLKSRVTISVDTSKNQFSLNLTSLTAADTALYYCARDYGSSSWYYYYGMDVWGQGTTVTVSS",
                "EVQTLSLTCTVSGGSISSGGYYWSWIRQPAGKGLEWIGRIYYSGYTGYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARGGPCSGGDCNSPWGQGTLVTVSS",
                "EVQVSVSCKASGYTFTSYYMHWVRQAPGQGLEWMGIINPSGGSTSYAQKFQGWVTMTRDTSTSTVYMELSRLRSDDTAVYYCARGYNVVPDGYNIDYWGQGTLVTVSS",
                "EVQVSSPALVKPTQTLTLTCTFSGFSLSTSGVGVGWIRQPPGKALEWLALIYWDDDKRYSPSLKARVTVSVDRSKNQVVLTMTNMDPVDTATYYCAHRNDSGSYWTWMDVWGQGTTVTISS",
                "EVQVSGGSISSSSYYWSWIRQPPGKGLEWIGEINHSGSTSYNPSLKSRVSISVDTSKNQFTLKLSSVTAADTAVYYCARTLQLLVVVPNFYFDYWGQGTLVTVSS",
                "EVQISGRFTISGGSVKGRFTISGGSVKDQFKISAVSVKGRFTVSGGSIKGRVTVSGSFTIPGGSVKGRFTVSGKFTIPGGSVMGRFTISG",
                "EVQTDTSYYWSWIRQPPGKGLEWIGEIYHSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARSHCSGGSCYLTCDVSGASCRASLAFWGQGTLVTVSS",
                "EVQTLTLTCTVSGYSISSGYYWGWIRQPPGKGLEWIGSIYYRGSSTSYNPSLKSRVSISIDTSKNQFSLKLSSVTAADTAVYYCAREGSGYSSGAFDIWGSAYYYGMDVWGQGTTVTVSSS",
                "EVQVSSNSAAWNWIRQPPGKGLEWIGEMYHSSSSTTYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAIYYCAKGWESSWADYWGQGTLVTVAS",
                "EVQTLSLTCTVSGGSISSGGYYWSWIRQHPGKGLEWIGYIDYSGSTNYNPSLKSRVSISVDTSKNQFSLKLSSVTAADTALYYCARGRSGIAVFQHFDYWGQGTLVTVSS",
                "EVQFWSGPTLVKPTQTLTLTCTFSGFSLSTSGMRVSWIRQSPSRGLEWLALIDWDDNKYYYSSSVRGRFTISRDDSKNTLDLQMNSLRDEDTAVYYCAKGGFHSSGWFGYYGMDVWGQGTMVTVSS",
                "EVQTLSLTCTVSGGSISSSNYWWTWIRQPPGKGLEFIAVISTGGSSTIYKPAVKGRVTISRDTSKNQFSLRLTSVTAADTAFYYCTREGHCSHSAFDIWGRGTLVTVSS",
                "EVQTLTLTCAISGDSMTGGYGMHWVRQPPGKGLEWIGFIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARDRYIAAYFGMDVWGQGTTVTVSS",
                "EVQTIDSLRAEDMYYWSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDTSINQFSLKLTSVTAADTAVYFCARQGYGGDSWGQGTLVTVSS",
                "EVQKFQGRVTMTEDTSTDTAYMELSSLRSEDTAVYYCARAQDRWVIGDYWYFDLWGRGTLVSVSS",
                "EVQVSSASVKVSCKASGYTFTDNWIGWVRQAPGQGLEWVGWINPNTGNPTYAQGFTGRFVFSLDTSVSTAYLQISSLKAEDTAVYYCARGLGAVAGAFDYWGQGTLVTVSS",
                "EVQIDTAYQWSWIRQPPGKGLEWIGEINHSGSVKYNSSLKSRVTISTDKSKNQFSLKVNSVTAADTALYYCARGRHESGSYFYFDSWGQGTLVTVSS",
                "EVQTLTLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISIDTSKNQFSLKLSSVTAADTAVYYCARLYYDSSGVPNYGMDVWGQGTTVTVSS",
                "EVQTLSLTCTVSGGSISSSNWWSWVRQPPGKGLEWIGEIYYSGSTYYNPSLKSRVTISVDKSKNHFSLKLSSVTAADTAVYYCARGLSGIFGYSGYWGQGTLVTVSS",
                "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKRQFSLKLSSVTAADTAVYYCARSYAAYCSGGSCFSEFFDYWGQGTLVTVSS",
                "EVQTLTLTCTVSGGSISSGSYYWSWIRQPPGKGLEYIGSLYTGATIYYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYFCARGGFGSAMTPLNWFDPWGQGTMVTVSS",
                "EVQMELSCASVSSVTVSSQWSLTLTCTVSGFSITGYYWSWIRQPPGKGLEWIGEIYHSGSIKYNPSLKSRVTISIDTSRNQFSLKLSSVTAADTAVYFCARAQCGGSGCGGYSFDYWGQGTVVTVSS",
                "EVQTLTLTCTVSGGSISSYYWSWIRQPPGKGLEWIGYIYYSGSTYYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCARIGGYFFDYWGQGTLVTVSS",
                "EVQTLSLTCTVSGGSISSYYWSWIRQPPGKGLEWIGYIYYSGSTYYNPSLKSRITISVDTSKNQFSLKLSSVTAADTAVYYCARITTSSHYDYWGQGTLVTVSS",
                "EVQMELSCAASGFTFDDYAMHWVRQAPGKGLEWVAFISYDGSNKYYADSVKGRFTISRDNPKNSLYLQMSSLRVEDTAVYYCAKDWTRYCGKDTLDYWGQGTLVTVSS",
                "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISIDSSKNQFSLKLSSVTAADTAVYYCARSPTRVVAANGLNYWGQGTMVTVSS",
                "EVQSSGRFTISRDNAKPVTYYWSWIRQPAGKGLEWIGRIYTSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARGAYLRRFWSGYFGMDVWGQGTTVTVSS",
                "EVQTLTLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCVRQVGYCSAFDIWGQGTLVTVSS",
                "EVQVSGGSISSYYWSWIRQPPGKGLEWIGEINHSGSTSYNPSLKSRVTISVDTSKNQFSLKLTSVTAADTAVYYCARRRQQLRRAPLVWGGGGGSPSWGQGTPVTISCEASGYTFNTRDTHWVRQAPGKGLEGVGYWSSTIDHNLPSLRDYVENFRNQFSLSITSMSAEDTAIYFCARSCGGHYYYDSSGMDVWGQGTTVTVSS",
                "EVQVSGISWNWIRQPPGKGLEWIGSFNWDSEYSPSVKSRLTWSADTSKNQFSLQLNSVTVEDSAVYYCARYSSSITIFGVVVWGQGTTVSASS",
                "EVQMELISIGSSYYYYGMDVWGQGTLVTVSSTNYNPNSVNPTQTLTLTSTVYDYWGQGTTVTVSSTYYNPYSVNPTQTLTLTGTT",
                "EVQVSGGYYWSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDTSKNQFSLKLTSVTAADTAVYFCARGPIWTKYYYDSSGAFDIWGQGTMVTVSS",
                "EVQTLSLTCTVSGGSISSSSNYWGWIRQPPGKGLEWIGSIYHSGSANYNPSLKSRVTISIDRSRNQFSLKLSSVTAADTAVYYCARDGGYGSGAFDIWGQGTMVTVSS",
                "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARSGSWGSFDYWGQGTLVTVSS",
                "EVQTSLVKPTQTLTLTCTFSGFSLSTSGVGVGWIRQPPGKALEWLALIYWNDDKRYSPSLEGRVTISVDTSTNQVSLKLNSVTTADTAVYYCTRGVGGAGPYYDYWGQGTLVTVSS",
                "EVQVSSYTGSVKGRFTISCKGSGYSISSYAMHWVRQAPGKGLEWMGWISPDDSDASYAQRFQGRITMTTDTSVSTNTLSLQMNSLRPEDTAVYFCARADNSGVKFDPWGQGTLVTVSS",
                "EVQHSGTSLVKPTQTLTLTCTFSGFSLSTRGVGVGWIRQPPGKALEWLALIYWDDDKRYSPSLASRVTLSKDTSKNQVVLTMTNMDPVDTATYYCARPSTVTLLWNYGMDVWGQGTTVTVSS",
                "EVQTLTLTCAISGDSISSNSAAWNWIRQSPSRGLEWLGRTYYNGTDYADSVKSRITINVDNSTNTLSLQMNSLTAEDTAVYFCARERGDYFDYWGQGTLVTVSS",
                "EVQMHWVRQAPGKGLEWVSYISSSGSTIYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDSALYHCAKDRAMMVRGLLDYWGQGTLVTVSS",
                "EVQISGDTAMQVSVKGRFTISCTVSGGSISSHFWTWIRQPPGKGLEWIGYIYYSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARGVWGSGSSIWGQGTTVTVSS",
                "EVQTLSLTCTVSGGSISSFYWSWIRQPPGKGLEWIGYIYYSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARAWVRWLSQYYFDYWGQGTLVTVSS",
                "EVQTLSLTCTVSGGSISSYYWSWIRQPPGKGLEWIGYIYYSGSTNYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCARTYFWSGYTDVWGQGTTVTVSS",
                "EVQVNWVRQAPGRGLEWISYIYSDSNKYYADSVKGRFTISRDDSKTLANLQMNSLKTEDTAVYYCARDHRRILTGYMDWGQGTLVTVSS",
                "EVQMDPSLKSRVTISIDTSKNQFSLRLNSVTAADTAVYYCAGVVSCSGGSPPFDYWGQGTLVTVSS",
                "EVQASGYTLVKPTQTLTLTCTFSGFSLSTSGVGVGWIRQPPGKALEWLALIFWDDDKRYSPSLKSRLTISKDTSKNQVVLTMTNMDPVDTATYYCAHDSPARLINYFDDYWGQGTLVTVSS",
                "EVQTLTLTCTVSGGSISSSSYFWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTMSIDKSKNQFSLKLSSVTAADTAVYYCARGKRREWYFDLRRGFDYWGQGTLVTVSS",
                "EVQTLSLTCTVSGGSISSGGYSWSWIRQHPGKGLEWIGYIYYSGSTYYNPSLKSRVTISVDTSKSQFSLKLSSVTAADTAVYYCARDRAAGILVRAFDIWGQGTLVTVSS",
                "EVQTSLVKPTQTLTLTCTFSGFSLSTSGMCVSWIRQPPGKALEWLALIDWDDDKYYSTSLKSRVTISIDTSKNHFSLQMNSLRAEDTAVYYCARAHRQSRGGAFDIWGQGTTVTVSS",
                "EVQTSGYYWSWIRQPPGKGLEWIGEIYHSGSTNYNPSLKSRVTMSVDTSKNQFSLKLSSVTAADTAVYYCARVSYYDSSWPPSPFDYWGQGTLVTVSS",
                "EVQTLTLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYHSGSTYYNPSLKTRVTISVDTSKNQFSLKLSSVTAADTAVYHCARVASGAGTGHYYFDYWGQGTLVTVSS",
                "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARDSGYGEYWLDPTNYFDYWGQGTLVTVSS",
                "EVQTLTLTCTFSGFTFNNNHIHWVRQAPGKGLEWMGGIIPIFGTANYAQKFQGRVTITADTSVTTSYMELSSLRSDDTAVYYCARDDGSGTTWSDTSYWGQGTLVTVSS",
                "EVQMELSSLRSEETATENVCTAYGGSLRLSCAASGFTFSSTSMHWVRQAPGKGLEWVAVISGSGGSTYYADSVKGRFTISRDNSKNTLYLQMNSLKTEDTAVYYCARYSSGPGGYFAFDIWGQGTTVTVSS",
                "EVQTLSLTCTVYGVGVKDYGWSWIRQPPGKGLEWIGYIYYSGSTNYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCAREPQTGVVAAFFDYWGQGTLVTVSS",
                "EVQTLTLTCTVSGGSISSGGYYWSWIRQHPGKGLEWIGYIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARVCGGSCYRSSWFDPWGQGTLVTVSS",
                "EVQVSGGYYWSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDTSPEQFSLKLTSVTAADTAVYYCAGGGGYDPYDFWSGYYSEYWGQGTLVTVSS",
                "EVQSLSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDTPHLQLSLTCSVTDRAVYYCARAVYFSGSNFFDYWGQGTLVTVSS",
                "EVQVSSNTLVKPTQTLTLTCTFSGFSLSTSGMCVSWIRQPPGKALEWLALIYWDDDKRYSPSLKSRVTISVDTSKNQFSLQLNSVTPEDSAAYYCARDGGRWFDFWGQGTLVVVSS",
                "EVQKFQGRVTMTEDTSKNTAYMELSSLRSEDTAVYYCARDRDTATGGYYGMDVWGQGTTVTVSS",
                "EVQTLSLTCTVSGGSISSGGFYWSWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAIYYCARGLWYSSGYLRAFDIWGQGTTVTVSS",
                "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYNPSVYKSLNTFSTDDSKSELSLNSLTAADTAMYFCARLERWDYYDVWGQGTTVTVSS",
                "EVQSSGYYLRVTTSRGPVTYYWSWIRQPPGRGLEWIGETFSGATIYHPSAVKGRVTMSVDTSKNQFSLKLSSVTAADTAVYFCARDLPHSSSPVYFDHWGQGTLVTVSS",
                "EVQTDSYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCARGGYYDNAFAWWFDLWGQGTLVTVSS",
                "EVQTLTLTCTVSGGSISSGGYYWNWIRQHPGKGLEWIGYIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARDRRGSSSHNWYLYDHWGQGTLVTVSS",
                "EVQTLSLTCTISGGSISSYYWSWIRQPPGKGLEWIGYIYYSGSTYYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCARVIVVGIPRAYDVWGQGTLVTVSS",
                "EVQISGDTAVYYWSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDKSRNSLSLKLSSVTAADTAVYFCARIRAPEAGGAWGTHDYWGQGTLVTVSS",
                "EVQVSGGSISSTSPMCVRQPPGDSLRLSCAASGFTFSSYAMSWVRQAPGKGLEWISRIKSSSSYTNYADSVKGRFTISRDDAKNSVYLQMDSLRADDTAVYYCARSLGYSSSWYFDLWGKGTTVTVSS",
                "EVQTLVTVSSPSWIRQPPGKALEWLAIDYSGDKYYSPSLKSRVTISVDTPNNQFSLKLTSVTAADTAVYHCARLRSRTLSSGPPFDYWGQGALVTVSP",
                "EVQIDYWYFDLWGQGTLVTVSSTELDTAMYYYGLGYAMKDFWQRTKVTVSSTTVTVSSTTATVSSTTTTVDTATYYVDVWGQGTLVTVSSTAWDTAVYHSGSTNFNPSLWGQGALVTVSSTSWTTNYYIDAWGQGTLVTVSSTDWDTALYYYDSSGTYYFDYWGQATLVTVSSTTWSTAYYYDGTSTSTLYP",
                "EVQTLTLTCTVSGGSISSGGYYWSWIRQHPGKGLEWIGYIYYSGSTYYNPSLKSRATISVDTSKNQFSLKLSSVTAADTAVYHCATLKGTALGWFDPWGQGTLVTVSS",
                "EVQVDTSNILFICGGAFAGLERIVSRRLGQGSIGFGASVGAKNTLESRHKGQSTLQLQETDVYGMVSDIVGMEDLLKFGLIPELVARLSTLVPMNSLSREALDVILLDTCRESFSQNQVELGVRLSVTPEAQDYLVRQSFDPAFGARPLRRAMQIYIEDPLSRAILSGEFAAEDTVVLRAEGDGLTFAPSA",
                "EVQVSSMTLVKPTQTLTLTCTFSGFPLSTYGIAWIRQPPGKALEWIGSIYHSGSTYYNPALKNRLTISKDTSKNQVVLTMTNMDPVDTATYYCAARPMLRRDAFDIWGQGTMVTVAS",
                "EVQTLTLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYYFGSTSYNPSLKSRVTISIDTSKNQFSLKLSSVTAADTAVYYCARAGSSSYSFGGQQLSNYFDVDVWGQGTTVTVSS",
                "EVQVSSMTAAWNDDTAYMELSCAASGFTFSSYWMHWVRQAPGKGLEWVAVISTGDSDTYIQSLQSRLTISKDTSKNQVVLTMTNMDPEDTAVYYCARHPHDENSGVGGVWGQGTLVTISS",
                "EVQTLSLTCTVSGGSISSYYWSWIRQPPGKGLEWIGSIYYSGSTNYNPSLKSRVTISVDKSKSQLNLKLSSVTAADTAVYFCARTASIFGVVKLLVPAALGFDYWGQGTLVTVSS",
                "EVQISGYYWSWIRQPNWMDVWGKGTTVTVSSASVKDYYWITIFGQGTMVTVSSTSVTGYSGSTFYSGATVTVSSTSVTVTSTYNYWGPYYSSTTVTVSSVSVTVSSTSAYYYGSYSSYTGSSYYNYGYRNWWGSGSNYWYSGYSSYYYSGSSSGYFYGYYSYYYGGYSSSRYYYYYG",
                "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAIYHCARHLGVSLAFDIWGRGTMVTVSS",
                "EVQTLSLTCTVSGGSISSYYWSWIRQPPGKGLEWIGYIYYSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARDPIAVVPTTGTFDYWGQGTLVTVSS",
                "EVQASGWIRQPPGKGLEWIGSISYSGSTYYNPSLKSRVTISVDKSKAQFSLKLNSVTAADTAVYYCARGVDWDFDFWGQGTLVIVSS",
                "EVQTSKNQVVLTMTNMDPSLKSCAASGPTLYLQMNSLTAVDTAMYYCARRFDVWGQGTLVSYKYSDAFDIWGQGTMVTVSS",
                "EVQVSGGNYYYWSWIRQPPGKALEWLALIYWDDDKYYSPSLKSRLTITKDTSKNQVVLTMTSLTAADTAVYYSARDWYGLEGIRGWLDPWGQGTLVTVSS",
                "EVQTLSLTCTVSGGSISSYYWAWIRQPPGRGLEWIGYIYYSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARLWGATMIVVGFDSWGQGTLVTVSS"
                ],
                "validation": [
                "EVQTLTLTCTVSGGSISSYYWSWIRQPPGKGLEWIGYIYYSGSTNYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCARHSIAASGSYCHFDYWGQGTLVTVSS",
                "EVQTLTLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISADKSKNTLYLQMNSLRAEDTAVYHCARDPTTGVTVAVFDYWGQGTLVTVSS",
                "EVQISGISWVRQPSLKSREEVSCKVSSNYSGSTHYWTWIRQPPGKALEWIGYIYYSGSTYYNPSLESRVSISVDTSKNQFSLKLSSVTAADTAVYYCARRSLMPYFQHWGQGILVTVSS",
                "EVQVSSASVKVSCKASGYTFTSYAMHWVRQAPGQGLEWMGWINPSANTGYAQKFQGRVTMTRDTSISTAYMELSRLRSDDTAVYYCARLPIWEHYYYFDYWGQGTLVTVSS",
                "EVQVSSDIWGQGTLVTVSSKDTSKNQFSLKLSSVTAADTAVYYCARAPRLGSDYWGQGTLVIVSSKVTSRSQFYFSVSASGGSAYGQSGYDAFDIWGQGNLVTVSSKGGSGGQFSLQLNSVTAADTAIYFCARSITIFGSTFFGMDVWGQGTLVTVSA",
                "EVQTLSLTCTVSGGSISSNEWMNWVRQVPGKGLEWIGFVDPSDSTRYSPSFKSRLTMSLDTSVSTAYLQWRSLKASDTAMYYCARTRGMVRGIYAGDCGLYYFGYWGQGTLVTVSS",
                "EVQVSGGKDTSKNQFSLKASCAASGFTFSRFAMTWIRQSPGQGLEWIGRIDYSGSEKYYSDSVKTRLAISKDNFKNQVSLRLNSVTAADTGTYYCARTLVTVSAPLKFHDAFDIWGRGTLVTVSS",
                "EVQVSSPALVKPTQTLTLTCTFSGFSLSTNGVGVGWIRQPPGKALEWLALIYWDDDKRYSPSLRSHVSISKDTSKNQVVLTMTNMDPVDTATYYCAHVRTIFGVVWFGQGELVTVSS",
                "EVQAPGHISSGGYYWSWIRQPPGKGLEWIGEIYHSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARGRGDYDFWSGYLLDYWGQGTLVTVSS",
                "EVQTLSLTCTVSGGSVSSGSYYWSWIRQPPGKGLQWIGYIYYSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARETAVAGFDDCWGQGTLVTVSS",
                "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVSISIDKSKNQFSLKLSSVTPADTAVYYCARQSGYGGGVDVWGQGTTVTVSS",
                "EVQTSTAYMYWVRQAPGPGMEWVSGIGGAGATQHYADSVKGRFTISRDNSKNTVYLQMNSLKTEDTAVYYCAKDWRDFDYWGQGTLVTVSS",
                "EVQVSGSVKGRFTISRDYADSTYYYGYNPSLKSRVTISVDTSKNQFSLQSRSVTASDTAVYYCARATGDYWGQGTLVTVSS",
                "EVQDSDDTVYAEVKKPRPTKASVYTSTAYTQTLTLTCAVYSGSFSYYWGWIRQSPGKGLEWIGSAKSTSGNTNYNPSLKSRVTISVDTSKNQFSLKVRSVTAADTAMYYCARGRYSGGDAFDIWGQGTMVTVSS",
                "EVQTLSLTCTVSGGSISSSSYSWSWIRQPPGKGLEWIGYIYYSGSTYYNPSLKSRVTISVDQSKNQFSLKLSSVTAADTAVYYCATPPDYWGQGTLVTVSS",
                "EVQVSGGSFSGYYWSWIRQPPGKGLEWIGSIHYSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARGRCVVGGGIEFGMDVWGQGTTVTVSS",
                "EVQMPPISDSRVTIGVKVSRTTYYWSWVRQPPGKGLEWIGEINHDGSANYNPSFNPSLKSRLTIARDNAVTAYMELTSLTAADTGTYYCARRALGGSFDIWGQGTMVTVSS",
                "EVQMELSCLGLTSHWGLGQGYSMNWVRQAPGKGLEWVAVISYDGSNTKFADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCVKGDIVVVAAAWGALDFDYWGQGTLVTVSS",
                "EVQISGYTGSVKGRFTISKDTSKNQFSLKLSSVTAADTAVYYCARYYDGFDYVWGSYYWGQGTLVTVSS",
                "EVQTLSLTCTVSGGSISSYYWSWIRQPPGKGLEWIGYVYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYHCARDYDTATSRCYWGPGTLVTVSS",
                "EVQTSGMELTELSQTLSLTCMVQGTSLRSKYWSWVRQAPGKGLEWIGEINHSGSTNYNPKLQARLTISIDTSKNQFSLRLTSVTAADTAVYYCAHVRYYDNWNPDYFDYWGQGTLVTVSS",
                "EVQTLTLTCAISGDSMTGGYGMHWVRQPPGKGLEWIGFIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARDRYIAAYFGMDVWGQGTTVTVSS",
                "EVQVSGGSISSSSYYWSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARDVGYSSPDAFDIWGQGTMVTVSS",
                "EVQISGMELKFQGRVTIMPTANVSGTNYAQSLETLSLTCTVSGGSISSGGYYWSWIRQPAGKGLEWIGYIYTSGTTNYNPSLKSRLTISVDMSKNQFSLKLSSVTAADTAVYFCARGKYHSSYGMDVWGQGTTVTVSS",
                "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARSTFDYSSDFWGQGTLVTVSS",
                "EVQTLTLTCTVSGDSVSSYWNWIRQSPGTGLEWIGRIYTSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARSGYMDYYDSSGYFYWNWFDPWGQGTLVTVSS",
                "EVQVRGSQLELSSLSSMELSWYYYYMDVWGSGPTLVKPTQTLTLTCTFSGFSLSTSGMCVTWVRQARGQALEWLARIGDDDKYYSTSLKTRLTISKDTSKNQVVLTMTNMDPVDTATYYCARGLEWGFDYWGQGTLVTVSS",
                "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARHSIAARSQRSHYWGQGTLVTVSS",
                "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSYYYSGSTYYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYSARDSSISSMDVWGQGTVVTVSS",
                "EVQMRGPGLVKPTQTLTLTCTFSGFSLSTSGMCVSWIRQPPGKALEWLAIIYWDDDKFYSTSLKTRLTITKDTSKNQVVLTMTNMDPVDTATYYCARLVRYYDILTGRFDPWGQGTLVTVSS",
                "EVQTLSLTCSFSGSGFTFHWVRQAPGKGLEWVAVISYDGSNKYYADSVKGRFTISRDNSKNTLYLQMTSLRAEDTAVYYCARDPVGGYPVHYYYGMDVWGQGTTVTVSS",
                "EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARDPMGTTSGGSIVVTIFGVVVPSVSVSP",
                "EVQMELSCAASGFTFSDYGMHWVRQAPGKGLEWVAVISYDGSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRDEDTAVYYCATDYQGDYSIDYWGQGTLVTVSS",
                "EVQVSGGYYWSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCASGSSYSGFDSYYDYWGQGTLVTVSS",
                "EVQTVSCKGSGYSFTAYINWVRQAPGQGLEWISRIDSSSTNTNYADSVKGRFTISRDNAKNTLFLQMNSLRAEDTAVYYCARGEGYWGQGTLVTVSS"
                ],
                "epochs": 1
            }
            })
            headers = {
            'Authorization': 'Token {}'.format(os.environ['BIOLMAI_TOKEN'])
            'Content-Type': 'application/json'
            }

            response = requests.request("POST", url, headers=headers, data=payload)

            print(response.text)



    .. tab-item:: R
        :sync: r

        .. code:: R

            ibrary(RCurl)
            headers = c(
            'Authorization' = paste('Token', Sys.getenv('BIOLMAI_TOKEN')),
            "Content-Type" = "application/json"
            )
            params = "{
            \"pipeline\": \"finetune_protgpt2_generator\",
            \"input_json\": {
                \"max_train\": 2000,
                \"max_validate\": 500,
                \"train\": [
                \"EVQSGSTNYNPSLKSRVTISVDKSQFSLKLTSVTVADTATYYCARGRFGSSGYGMDVWGQGTTVSVSS\",
                \"EVQTLTLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARGERRYSSVFYFDYWGQGILVTVSS\",
                \"EVQHWINQAPGYYWSWIRQPPGKGLEWIGEINHDGSTNYNPSLKSRVTISVDTSKNQFSLNLTSLTAADTALYYCARDYGSSSWYYYYGMDVWGQGTTVTVSS\",
                \"EVQTLSLTCTVSGGSISSGGYYWSWIRQPAGKGLEWIGRIYYSGYTGYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARGGPCSGGDCNSPWGQGTLVTVSS\",
                \"EVQVSVSCKASGYTFTSYYMHWVRQAPGQGLEWMGIINPSGGSTSYAQKFQGWVTMTRDTSTSTVYMELSRLRSDDTAVYYCARGYNVVPDGYNIDYWGQGTLVTVSS\",
                \"EVQVSSPALVKPTQTLTLTCTFSGFSLSTSGVGVGWIRQPPGKALEWLALIYWDDDKRYSPSLKARVTVSVDRSKNQVVLTMTNMDPVDTATYYCAHRNDSGSYWTWMDVWGQGTTVTISS\",
                \"EVQVSGGSISSSSYYWSWIRQPPGKGLEWIGEINHSGSTSYNPSLKSRVSISVDTSKNQFTLKLSSVTAADTAVYYCARTLQLLVVVPNFYFDYWGQGTLVTVSS\",
                \"EVQISGRFTISGGSVKGRFTISGGSVKDQFKISAVSVKGRFTVSGGSIKGRVTVSGSFTIPGGSVKGRFTVSGKFTIPGGSVMGRFTISG\",
                \"EVQTDTSYYWSWIRQPPGKGLEWIGEIYHSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARSHCSGGSCYLTCDVSGASCRASLAFWGQGTLVTVSS\",
                \"EVQTLTLTCTVSGYSISSGYYWGWIRQPPGKGLEWIGSIYYRGSSTSYNPSLKSRVSISIDTSKNQFSLKLSSVTAADTAVYYCAREGSGYSSGAFDIWGSAYYYGMDVWGQGTTVTVSSS\",
                \"EVQVSSNSAAWNWIRQPPGKGLEWIGEMYHSSSSTTYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAIYYCAKGWESSWADYWGQGTLVTVAS\",
                \"EVQTLSLTCTVSGGSISSGGYYWSWIRQHPGKGLEWIGYIDYSGSTNYNPSLKSRVSISVDTSKNQFSLKLSSVTAADTALYYCARGRSGIAVFQHFDYWGQGTLVTVSS\",
                \"EVQFWSGPTLVKPTQTLTLTCTFSGFSLSTSGMRVSWIRQSPSRGLEWLALIDWDDNKYYYSSSVRGRFTISRDDSKNTLDLQMNSLRDEDTAVYYCAKGGFHSSGWFGYYGMDVWGQGTMVTVSS\",
                \"EVQTLSLTCTVSGGSISSSNYWWTWIRQPPGKGLEFIAVISTGGSSTIYKPAVKGRVTISRDTSKNQFSLRLTSVTAADTAFYYCTREGHCSHSAFDIWGRGTLVTVSS\",
                \"EVQTLTLTCAISGDSMTGGYGMHWVRQPPGKGLEWIGFIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARDRYIAAYFGMDVWGQGTTVTVSS\",
                \"EVQTIDSLRAEDMYYWSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDTSINQFSLKLTSVTAADTAVYFCARQGYGGDSWGQGTLVTVSS\",
                \"EVQKFQGRVTMTEDTSTDTAYMELSSLRSEDTAVYYCARAQDRWVIGDYWYFDLWGRGTLVSVSS\",
                \"EVQVSSASVKVSCKASGYTFTDNWIGWVRQAPGQGLEWVGWINPNTGNPTYAQGFTGRFVFSLDTSVSTAYLQISSLKAEDTAVYYCARGLGAVAGAFDYWGQGTLVTVSS\",
                \"EVQIDTAYQWSWIRQPPGKGLEWIGEINHSGSVKYNSSLKSRVTISTDKSKNQFSLKVNSVTAADTALYYCARGRHESGSYFYFDSWGQGTLVTVSS\",
                \"EVQTLTLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISIDTSKNQFSLKLSSVTAADTAVYYCARLYYDSSGVPNYGMDVWGQGTTVTVSS\",
                \"EVQTLSLTCTVSGGSISSSNWWSWVRQPPGKGLEWIGEIYYSGSTYYNPSLKSRVTISVDKSKNHFSLKLSSVTAADTAVYYCARGLSGIFGYSGYWGQGTLVTVSS\",
                \"EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKRQFSLKLSSVTAADTAVYYCARSYAAYCSGGSCFSEFFDYWGQGTLVTVSS\",
                \"EVQTLTLTCTVSGGSISSGSYYWSWIRQPPGKGLEYIGSLYTGATIYYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYFCARGGFGSAMTPLNWFDPWGQGTMVTVSS\",
                \"EVQMELSCASVSSVTVSSQWSLTLTCTVSGFSITGYYWSWIRQPPGKGLEWIGEIYHSGSIKYNPSLKSRVTISIDTSRNQFSLKLSSVTAADTAVYFCARAQCGGSGCGGYSFDYWGQGTVVTVSS\",
                \"EVQTLTLTCTVSGGSISSYYWSWIRQPPGKGLEWIGYIYYSGSTYYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCARIGGYFFDYWGQGTLVTVSS\",
                \"EVQTLSLTCTVSGGSISSYYWSWIRQPPGKGLEWIGYIYYSGSTYYNPSLKSRITISVDTSKNQFSLKLSSVTAADTAVYYCARITTSSHYDYWGQGTLVTVSS\",
                \"EVQMELSCAASGFTFDDYAMHWVRQAPGKGLEWVAFISYDGSNKYYADSVKGRFTISRDNPKNSLYLQMSSLRVEDTAVYYCAKDWTRYCGKDTLDYWGQGTLVTVSS\",
                \"EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISIDSSKNQFSLKLSSVTAADTAVYYCARSPTRVVAANGLNYWGQGTMVTVSS\",
                \"EVQSSGRFTISRDNAKPVTYYWSWIRQPAGKGLEWIGRIYTSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARGAYLRRFWSGYFGMDVWGQGTTVTVSS\",
                \"EVQTLTLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCVRQVGYCSAFDIWGQGTLVTVSS\",
                \"EVQVSGGSISSYYWSWIRQPPGKGLEWIGEINHSGSTSYNPSLKSRVTISVDTSKNQFSLKLTSVTAADTAVYYCARRRQQLRRAPLVWGGGGGSPSWGQGTPVTISCEASGYTFNTRDTHWVRQAPGKGLEGVGYWSSTIDHNLPSLRDYVENFRNQFSLSITSMSAEDTAIYFCARSCGGHYYYDSSGMDVWGQGTTVTVSS\",
                \"EVQVSGISWNWIRQPPGKGLEWIGSFNWDSEYSPSVKSRLTWSADTSKNQFSLQLNSVTVEDSAVYYCARYSSSITIFGVVVWGQGTTVSASS\",
                \"EVQMELISIGSSYYYYGMDVWGQGTLVTVSSTNYNPNSVNPTQTLTLTSTVYDYWGQGTTVTVSSTYYNPYSVNPTQTLTLTGTT\",
                \"EVQVSGGYYWSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDTSKNQFSLKLTSVTAADTAVYFCARGPIWTKYYYDSSGAFDIWGQGTMVTVSS\",
                \"EVQTLSLTCTVSGGSISSSSNYWGWIRQPPGKGLEWIGSIYHSGSANYNPSLKSRVTISIDRSRNQFSLKLSSVTAADTAVYYCARDGGYGSGAFDIWGQGTMVTVSS\",
                \"EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARSGSWGSFDYWGQGTLVTVSS\",
                \"EVQTSLVKPTQTLTLTCTFSGFSLSTSGVGVGWIRQPPGKALEWLALIYWNDDKRYSPSLEGRVTISVDTSTNQVSLKLNSVTTADTAVYYCTRGVGGAGPYYDYWGQGTLVTVSS\",
                \"EVQVSSYTGSVKGRFTISCKGSGYSISSYAMHWVRQAPGKGLEWMGWISPDDSDASYAQRFQGRITMTTDTSVSTNTLSLQMNSLRPEDTAVYFCARADNSGVKFDPWGQGTLVTVSS\",
                \"EVQHSGTSLVKPTQTLTLTCTFSGFSLSTRGVGVGWIRQPPGKALEWLALIYWDDDKRYSPSLASRVTLSKDTSKNQVVLTMTNMDPVDTATYYCARPSTVTLLWNYGMDVWGQGTTVTVSS\",
                \"EVQTLTLTCAISGDSISSNSAAWNWIRQSPSRGLEWLGRTYYNGTDYADSVKSRITINVDNSTNTLSLQMNSLTAEDTAVYFCARERGDYFDYWGQGTLVTVSS\",
                \"EVQMHWVRQAPGKGLEWVSYISSSGSTIYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDSALYHCAKDRAMMVRGLLDYWGQGTLVTVSS\",
                \"EVQISGDTAMQVSVKGRFTISCTVSGGSISSHFWTWIRQPPGKGLEWIGYIYYSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARGVWGSGSSIWGQGTTVTVSS\",
                \"EVQTLSLTCTVSGGSISSFYWSWIRQPPGKGLEWIGYIYYSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARAWVRWLSQYYFDYWGQGTLVTVSS\",
                \"EVQTLSLTCTVSGGSISSYYWSWIRQPPGKGLEWIGYIYYSGSTNYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCARTYFWSGYTDVWGQGTTVTVSS\",
                \"EVQVNWVRQAPGRGLEWISYIYSDSNKYYADSVKGRFTISRDDSKTLANLQMNSLKTEDTAVYYCARDHRRILTGYMDWGQGTLVTVSS\",
                \"EVQMDPSLKSRVTISIDTSKNQFSLRLNSVTAADTAVYYCAGVVSCSGGSPPFDYWGQGTLVTVSS\",
                \"EVQASGYTLVKPTQTLTLTCTFSGFSLSTSGVGVGWIRQPPGKALEWLALIFWDDDKRYSPSLKSRLTISKDTSKNQVVLTMTNMDPVDTATYYCAHDSPARLINYFDDYWGQGTLVTVSS\",
                \"EVQTLTLTCTVSGGSISSSSYFWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTMSIDKSKNQFSLKLSSVTAADTAVYYCARGKRREWYFDLRRGFDYWGQGTLVTVSS\",
                \"EVQTLSLTCTVSGGSISSGGYSWSWIRQHPGKGLEWIGYIYYSGSTYYNPSLKSRVTISVDTSKSQFSLKLSSVTAADTAVYYCARDRAAGILVRAFDIWGQGTLVTVSS\",
                \"EVQTSLVKPTQTLTLTCTFSGFSLSTSGMCVSWIRQPPGKALEWLALIDWDDDKYYSTSLKSRVTISIDTSKNHFSLQMNSLRAEDTAVYYCARAHRQSRGGAFDIWGQGTTVTVSS\",
                \"EVQTSGYYWSWIRQPPGKGLEWIGEIYHSGSTNYNPSLKSRVTMSVDTSKNQFSLKLSSVTAADTAVYYCARVSYYDSSWPPSPFDYWGQGTLVTVSS\",
                \"EVQTLTLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYHSGSTYYNPSLKTRVTISVDTSKNQFSLKLSSVTAADTAVYHCARVASGAGTGHYYFDYWGQGTLVTVSS\",
                \"EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARDSGYGEYWLDPTNYFDYWGQGTLVTVSS\",
                \"EVQTLTLTCTFSGFTFNNNHIHWVRQAPGKGLEWMGGIIPIFGTANYAQKFQGRVTITADTSVTTSYMELSSLRSDDTAVYYCARDDGSGTTWSDTSYWGQGTLVTVSS\",
                \"EVQMELSSLRSEETATENVCTAYGGSLRLSCAASGFTFSSTSMHWVRQAPGKGLEWVAVISGSGGSTYYADSVKGRFTISRDNSKNTLYLQMNSLKTEDTAVYYCARYSSGPGGYFAFDIWGQGTTVTVSS\",
                \"EVQTLSLTCTVYGVGVKDYGWSWIRQPPGKGLEWIGYIYYSGSTNYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCAREPQTGVVAAFFDYWGQGTLVTVSS\",
                \"EVQTLTLTCTVSGGSISSGGYYWSWIRQHPGKGLEWIGYIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARVCGGSCYRSSWFDPWGQGTLVTVSS\",
                \"EVQVSGGYYWSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDTSPEQFSLKLTSVTAADTAVYYCAGGGGYDPYDFWSGYYSEYWGQGTLVTVSS\",
                \"EVQSLSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDTPHLQLSLTCSVTDRAVYYCARAVYFSGSNFFDYWGQGTLVTVSS\",
                \"EVQVSSNTLVKPTQTLTLTCTFSGFSLSTSGMCVSWIRQPPGKALEWLALIYWDDDKRYSPSLKSRVTISVDTSKNQFSLQLNSVTPEDSAAYYCARDGGRWFDFWGQGTLVVVSS\",
                \"EVQKFQGRVTMTEDTSKNTAYMELSSLRSEDTAVYYCARDRDTATGGYYGMDVWGQGTTVTVSS\",
                \"EVQTLSLTCTVSGGSISSGGFYWSWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAIYYCARGLWYSSGYLRAFDIWGQGTTVTVSS\",
                \"EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYNPSVYKSLNTFSTDDSKSELSLNSLTAADTAMYFCARLERWDYYDVWGQGTTVTVSS\",
                \"EVQSSGYYLRVTTSRGPVTYYWSWIRQPPGRGLEWIGETFSGATIYHPSAVKGRVTMSVDTSKNQFSLKLSSVTAADTAVYFCARDLPHSSSPVYFDHWGQGTLVTVSS\",
                \"EVQTDSYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCARGGYYDNAFAWWFDLWGQGTLVTVSS\",
                \"EVQTLTLTCTVSGGSISSGGYYWNWIRQHPGKGLEWIGYIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARDRRGSSSHNWYLYDHWGQGTLVTVSS\",
                \"EVQTLSLTCTISGGSISSYYWSWIRQPPGKGLEWIGYIYYSGSTYYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCARVIVVGIPRAYDVWGQGTLVTVSS\",
                \"EVQISGDTAVYYWSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDKSRNSLSLKLSSVTAADTAVYFCARIRAPEAGGAWGTHDYWGQGTLVTVSS\",
                \"EVQVSGGSISSTSPMCVRQPPGDSLRLSCAASGFTFSSYAMSWVRQAPGKGLEWISRIKSSSSYTNYADSVKGRFTISRDDAKNSVYLQMDSLRADDTAVYYCARSLGYSSSWYFDLWGKGTTVTVSS\",
                \"EVQTLVTVSSPSWIRQPPGKALEWLAIDYSGDKYYSPSLKSRVTISVDTPNNQFSLKLTSVTAADTAVYHCARLRSRTLSSGPPFDYWGQGALVTVSP\",
                \"EVQIDYWYFDLWGQGTLVTVSSTELDTAMYYYGLGYAMKDFWQRTKVTVSSTTVTVSSTTATVSSTTTTVDTATYYVDVWGQGTLVTVSSTAWDTAVYHSGSTNFNPSLWGQGALVTVSSTSWTTNYYIDAWGQGTLVTVSSTDWDTALYYYDSSGTYYFDYWGQATLVTVSSTTWSTAYYYDGTSTSTLYP\",
                \"EVQTLTLTCTVSGGSISSGGYYWSWIRQHPGKGLEWIGYIYYSGSTYYNPSLKSRATISVDTSKNQFSLKLSSVTAADTAVYHCATLKGTALGWFDPWGQGTLVTVSS\",
                \"EVQVDTSNILFICGGAFAGLERIVSRRLGQGSIGFGASVGAKNTLESRHKGQSTLQLQETDVYGMVSDIVGMEDLLKFGLIPELVARLSTLVPMNSLSREALDVILLDTCRESFSQNQVELGVRLSVTPEAQDYLVRQSFDPAFGARPLRRAMQIYIEDPLSRAILSGEFAAEDTVVLRAEGDGLTFAPSA\",
                \"EVQVSSMTLVKPTQTLTLTCTFSGFPLSTYGIAWIRQPPGKALEWIGSIYHSGSTYYNPALKNRLTISKDTSKNQVVLTMTNMDPVDTATYYCAARPMLRRDAFDIWGQGTMVTVAS\",
                \"EVQTLTLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYYFGSTSYNPSLKSRVTISIDTSKNQFSLKLSSVTAADTAVYYCARAGSSSYSFGGQQLSNYFDVDVWGQGTTVTVSS\",
                \"EVQVSSMTAAWNDDTAYMELSCAASGFTFSSYWMHWVRQAPGKGLEWVAVISTGDSDTYIQSLQSRLTISKDTSKNQVVLTMTNMDPEDTAVYYCARHPHDENSGVGGVWGQGTLVTISS\",
                \"EVQTLSLTCTVSGGSISSYYWSWIRQPPGKGLEWIGSIYYSGSTNYNPSLKSRVTISVDKSKSQLNLKLSSVTAADTAVYFCARTASIFGVVKLLVPAALGFDYWGQGTLVTVSS\",
                \"EVQISGYYWSWIRQPNWMDVWGKGTTVTVSSASVKDYYWITIFGQGTMVTVSSTSVTGYSGSTFYSGATVTVSSTSVTVTSTYNYWGPYYSSTTVTVSSVSVTVSSTSAYYYGSYSSYTGSSYYNYGYRNWWGSGSNYWYSGYSSYYYSGSSSGYFYGYYSYYYGGYSSSRYYYYYG\",
                \"EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAIYHCARHLGVSLAFDIWGRGTMVTVSS\",
                \"EVQTLSLTCTVSGGSISSYYWSWIRQPPGKGLEWIGYIYYSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARDPIAVVPTTGTFDYWGQGTLVTVSS\",
                \"EVQASGWIRQPPGKGLEWIGSISYSGSTYYNPSLKSRVTISVDKSKAQFSLKLNSVTAADTAVYYCARGVDWDFDFWGQGTLVIVSS\",
                \"EVQTSKNQVVLTMTNMDPSLKSCAASGPTLYLQMNSLTAVDTAMYYCARRFDVWGQGTLVSYKYSDAFDIWGQGTMVTVSS\",
                \"EVQVSGGNYYYWSWIRQPPGKALEWLALIYWDDDKYYSPSLKSRLTITKDTSKNQVVLTMTSLTAADTAVYYSARDWYGLEGIRGWLDPWGQGTLVTVSS\",
                \"EVQTLSLTCTVSGGSISSYYWAWIRQPPGRGLEWIGYIYYSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARLWGATMIVVGFDSWGQGTLVTVSS\"
                ],
                \"validation\": [
                \"EVQTLTLTCTVSGGSISSYYWSWIRQPPGKGLEWIGYIYYSGSTNYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCARHSIAASGSYCHFDYWGQGTLVTVSS\",
                \"EVQTLTLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISADKSKNTLYLQMNSLRAEDTAVYHCARDPTTGVTVAVFDYWGQGTLVTVSS\",
                \"EVQISGISWVRQPSLKSREEVSCKVSSNYSGSTHYWTWIRQPPGKALEWIGYIYYSGSTYYNPSLESRVSISVDTSKNQFSLKLSSVTAADTAVYYCARRSLMPYFQHWGQGILVTVSS\",
                \"EVQVSSASVKVSCKASGYTFTSYAMHWVRQAPGQGLEWMGWINPSANTGYAQKFQGRVTMTRDTSISTAYMELSRLRSDDTAVYYCARLPIWEHYYYFDYWGQGTLVTVSS\",
                \"EVQVSSDIWGQGTLVTVSSKDTSKNQFSLKLSSVTAADTAVYYCARAPRLGSDYWGQGTLVIVSSKVTSRSQFYFSVSASGGSAYGQSGYDAFDIWGQGNLVTVSSKGGSGGQFSLQLNSVTAADTAIYFCARSITIFGSTFFGMDVWGQGTLVTVSA\",
                \"EVQTLSLTCTVSGGSISSNEWMNWVRQVPGKGLEWIGFVDPSDSTRYSPSFKSRLTMSLDTSVSTAYLQWRSLKASDTAMYYCARTRGMVRGIYAGDCGLYYFGYWGQGTLVTVSS\",
                \"EVQVSGGKDTSKNQFSLKASCAASGFTFSRFAMTWIRQSPGQGLEWIGRIDYSGSEKYYSDSVKTRLAISKDNFKNQVSLRLNSVTAADTGTYYCARTLVTVSAPLKFHDAFDIWGRGTLVTVSS\",
                \"EVQVSSPALVKPTQTLTLTCTFSGFSLSTNGVGVGWIRQPPGKALEWLALIYWDDDKRYSPSLRSHVSISKDTSKNQVVLTMTNMDPVDTATYYCAHVRTIFGVVWFGQGELVTVSS\",
                \"EVQAPGHISSGGYYWSWIRQPPGKGLEWIGEIYHSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARGRGDYDFWSGYLLDYWGQGTLVTVSS\",
                \"EVQTLSLTCTVSGGSVSSGSYYWSWIRQPPGKGLQWIGYIYYSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARETAVAGFDDCWGQGTLVTVSS\",
                \"EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVSISIDKSKNQFSLKLSSVTPADTAVYYCARQSGYGGGVDVWGQGTTVTVSS\",
                \"EVQTSTAYMYWVRQAPGPGMEWVSGIGGAGATQHYADSVKGRFTISRDNSKNTVYLQMNSLKTEDTAVYYCAKDWRDFDYWGQGTLVTVSS\",
                \"EVQVSGSVKGRFTISRDYADSTYYYGYNPSLKSRVTISVDTSKNQFSLQSRSVTASDTAVYYCARATGDYWGQGTLVTVSS\",
                \"EVQDSDDTVYAEVKKPRPTKASVYTSTAYTQTLTLTCAVYSGSFSYYWGWIRQSPGKGLEWIGSAKSTSGNTNYNPSLKSRVTISVDTSKNQFSLKVRSVTAADTAMYYCARGRYSGGDAFDIWGQGTMVTVSS\",
                \"EVQTLSLTCTVSGGSISSSSYSWSWIRQPPGKGLEWIGYIYYSGSTYYNPSLKSRVTISVDQSKNQFSLKLSSVTAADTAVYYCATPPDYWGQGTLVTVSS\",
                \"EVQVSGGSFSGYYWSWIRQPPGKGLEWIGSIHYSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARGRCVVGGGIEFGMDVWGQGTTVTVSS\",
                \"EVQMPPISDSRVTIGVKVSRTTYYWSWVRQPPGKGLEWIGEINHDGSANYNPSFNPSLKSRLTIARDNAVTAYMELTSLTAADTGTYYCARRALGGSFDIWGQGTMVTVSS\",
                \"EVQMELSCLGLTSHWGLGQGYSMNWVRQAPGKGLEWVAVISYDGSNTKFADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCVKGDIVVVAAAWGALDFDYWGQGTLVTVSS\",
                \"EVQISGYTGSVKGRFTISKDTSKNQFSLKLSSVTAADTAVYYCARYYDGFDYVWGSYYWGQGTLVTVSS\",
                \"EVQTLSLTCTVSGGSISSYYWSWIRQPPGKGLEWIGYVYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYHCARDYDTATSRCYWGPGTLVTVSS\",
                \"EVQTSGMELTELSQTLSLTCMVQGTSLRSKYWSWVRQAPGKGLEWIGEINHSGSTNYNPKLQARLTISIDTSKNQFSLRLTSVTAADTAVYYCAHVRYYDNWNPDYFDYWGQGTLVTVSS\",
                \"EVQTLTLTCAISGDSMTGGYGMHWVRQPPGKGLEWIGFIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARDRYIAAYFGMDVWGQGTTVTVSS\",
                \"EVQVSGGSISSSSYYWSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARDVGYSSPDAFDIWGQGTMVTVSS\",
                \"EVQISGMELKFQGRVTIMPTANVSGTNYAQSLETLSLTCTVSGGSISSGGYYWSWIRQPAGKGLEWIGYIYTSGTTNYNPSLKSRLTISVDMSKNQFSLKLSSVTAADTAVYFCARGKYHSSYGMDVWGQGTTVTVSS\",
                \"EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARSTFDYSSDFWGQGTLVTVSS\",
                \"EVQTLTLTCTVSGDSVSSYWNWIRQSPGTGLEWIGRIYTSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARSGYMDYYDSSGYFYWNWFDPWGQGTLVTVSS\",
                \"EVQVRGSQLELSSLSSMELSWYYYYMDVWGSGPTLVKPTQTLTLTCTFSGFSLSTSGMCVTWVRQARGQALEWLARIGDDDKYYSTSLKTRLTISKDTSKNQVVLTMTNMDPVDTATYYCARGLEWGFDYWGQGTLVTVSS\",
                \"EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCARHSIAARSQRSHYWGQGTLVTVSS\",
                \"EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSYYYSGSTYYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYSARDSSISSMDVWGQGTVVTVSS\",
                \"EVQMRGPGLVKPTQTLTLTCTFSGFSLSTSGMCVSWIRQPPGKALEWLAIIYWDDDKFYSTSLKTRLTITKDTSKNQVVLTMTNMDPVDTATYYCARLVRYYDILTGRFDPWGQGTLVTVSS\",
                \"EVQTLSLTCSFSGSGFTFHWVRQAPGKGLEWVAVISYDGSNKYYADSVKGRFTISRDNSKNTLYLQMTSLRAEDTAVYYCARDPVGGYPVHYYYGMDVWGQGTTVTVSS\",
                \"EVQTLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYSGSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYFCARDPMGTTSGGSIVVTIFGVVVPSVSVSP\",
                \"EVQMELSCAASGFTFSDYGMHWVRQAPGKGLEWVAVISYDGSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRDEDTAVYYCATDYQGDYSIDYWGQGTLVTVSS\",
                \"EVQVSGGYYWSWIRQPPGKGLEWIGEINHSGSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCASGSSYSGFDSYYDYWGQGTLVTVSS\",
                \"EVQTVSCKGSGYSFTAYINWVRQAPGQGLEWISRIDSSSTNTNYADSVKGRFTISRDNAKNTLFLQMNSLRAEDTAVYYCARGEGYWGQGTLVTVSS\"
                ],
                \"epochs\": 1
            }
            }"
            res <- postForm("https://biolm.ai/api/v1/finetune_run/", .opts=list(postfields = params, httpheader = headers, followlocation = TRUE), style = "httppost")
            cat(res)

+++++++++++++
Definitions
+++++++++++++
max_train:
    The maximum number of training examples to use. The value 2000 suggests that the model will be trained on up to 2000 sequences.

max_validate:
    The maximum number of validation examples to use. The value 500 indicates that up to 500 sequences will be used for validating the model during training.

train:
    An array of strings, where each string represents a training example (protein sequences).

validation:
    Similarly, this is an array of validation sequences to evaluate the model's performance during training.

epochs:
    The number of times the training process will iterate over the entire training dataset. An epoch is one complete pass through the dataset. Here, it's set to 1, which means the dataset will be passed through once.


^^^^^^^^^^^^^
JSON Response
^^^^^^^^^^^^^

.. dropdown:: Expand Example Response

    .. code:: json

        {
        "id": "14",
        "pipeline": {
            "id": "1",
            "pipeline_slug": "finetune_protgpt2_generator"
        },
        "start_time": null,
        "created_at": "2023-02-14T06:47:07.934402-08:00",
        "end_time": null,
        "status": "scheduled",
        "algorithm": null
        }

+++++++++++++
Definitions
+++++++++++++
Start_time:
    This field records the time when the task started processing. Null indicates that the process has not started yet.

created_at:
    The timestamp when the task was created or submitted to the system. It is in ISO 8601 date and time format with timezone information.

end_time:
    Similar to start_time, this would record when the task finished processing. Null indicates it has not finished yet or has not started.

status:
    This indicates the current state of the task. "scheduled" means that the task has been scheduled to run but has not yet started.

algorithm:
    This indicates which algorithm or method is being used for the task. null suggests that this information is either not applicable, not decided yet, or simply not provided in the response.


---------------------------------------------
API Usage: Generate Protein from FT ProtGPT2
---------------------------------------------

URL: https://biolm.ai/api/v1/models/demofixed_finetune_protgpt2_generator_15/generate/

^^^^^^^^^^^^^^^
Making Requests
^^^^^^^^^^^^^^^

.. tab-set::

    .. tab-item:: Curl
        :sync: curl

        .. code:: shell

            curl --location 'https://biolm.ai/api/v1/models/demofixed_finetune_protgpt2_generator_15/generate/' \
            --header "Authorization: Token $BIOLMAI_TOKEN" \
            --header 'Content-Type: application/json' \
            --data '{
            "instances": [{
                "data": {
                    "text": "M",
                    "max_length": 256,
                    "repetition_penalty": 1.2,
                    "temperature": 0.7,
                    "num_samples": 2,
                    "top_k": 1024,
                    "do_sample": true
                }
            }]
            }'

    .. tab-item:: Python Requests
        :sync: python

        .. code:: python

            import requests
            import json

            url = "https://biolm.ai/api/v1/models/demofixed_finetune_protgpt2_generator_15/generate/"

            payload = json.dumps({
            "instances": [
                {
                "data": {
                    "text": "M",
                    "max_length": 256,
                    "repetition_penalty": 1.2,
                    "temperature": 0.7,
                    "num_samples": 2,
                    "top_k": 1024,
                    "do_sample": True
                }
                }
            ]
            })
            headers = {
            'Authorization': 'Token {}'.format(os.environ['BIOLMAI_TOKEN']),
            'Content-Type': 'application/json'
            }

            response = requests.request("POST", url, headers=headers, data=payload)

            print(response.text)

    .. tab-item:: R
        :sync: r

        .. code:: R

            library(RCurl)
            headers = c(
            'Authorization' = paste('Token', Sys.getenv('BIOLMAI_TOKEN')),
            "Content-Type" = "application/json"
            )
            params = "{
            \"instances\": [
                {
                \"data\": {
                    \"text\": \"M\",
                    \"max_length\": 256,
                    \"repetition_penalty\": 1.2,
                    \"temperature\": 0.7,
                    \"num_samples\": 2,
                    \"top_k\": 1024,
                    \"do_sample\": true
                }
                }
            ]
            }"
            res <- postForm("https://biolm.ai/api/v1/models/demofixed_finetune_protgpt2_generator_15/generate/", .opts=list(postfields = params, httpheader = headers, followlocation = TRUE), style = "httppost")
            cat(res)


^^^^^^^^^^^^^
JSON Response
^^^^^^^^^^^^^

.. dropdown:: Expand Example Response

    .. code:: json

        {
        "predictions": {
            "generated": [
            {
                "text": "MAGGSGGYGGVGPGGGGGCGGRGGHGGHGGQGGAGGHGKHGVHGSHGGNGGLGGNGGYGSGGGGGGGGGGGGSGGSGSGSGSGSGGGQGAYGQSGGSGDGSSGSGGGGGGGGGGGGGGGGSGSSGSGGGGGQGAYGGYGSGGGSGGSGGGGGGGSSGGGLDLS",
                "perplexity": 137.22583486792615
            },
            {
                "text": "MGGGGGGRERWGGRRGRGREGEERGGRSGGEGKEGRRREEGREEGRGGRGERGGGEGEREEXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXEEEGEGEGEGEERRRGRREGEGRRRRRERRGEEGRGRGEERRGGRRKEERRRKRRGGRGGGRRGEKRRGRREEGGRKGEGKGRGKRREKEGEGEGERRGKEKEKKRKKEGEEEGGGERRGDVWMGGRGGGREGKGGKGRKGGGGKEGRKGEGGGGGGGKEERRKEGGEGRRKRRGKRERRKRGRKGGKREGEGGEREGGEEREGRGGEERGKGKGEREEEGEKGGGGGRGGRGGRGRGGRKEGGRGGRKRGWGGKGGKREGKGERRGRKRR",
                "perplexity": 94.07628602747525
            }
            ]
        }
        }

^^^^^^^^^^^^^^^^^^^^
Request Definitions
^^^^^^^^^^^^^^^^^^^^

text:
    The initial text prompt to start the sequence generation. In this case, "M" could indicate the model should generate protein sequences starting with the amino acid Methionine, denoted by "M" in single-letter amino acid codes.

max_length:
    The maximum length of the sequence to generate. The model will generate sequences up to 256 characters long.

repetition_penalty:
    A factor that penalizes repetition in the generated text to encourage diversity. A value of 1.2 makes it slightly more likely to generate different amino acids rather than repeating the same ones.

temperature:
    A parameter controlling the randomness of the generation. A lower temperature (0.7 in this case) results in more predictable text, while a higher temperature would result in more varied outputs.

num_samples:
    The number of sequences to generate in this request. It's set to 2, meaning the API will generate two different sequences based on the input parameters.

top_k:
    This parameter restricts the model's sampling to the top-k most likely next characters. A high value like 1024 allows almost all characters to be considered, only slightly narrowing the distribution.

do_sample:
    A boolean indicating whether sampling should be used. true means that the model will sample from the probability distribution for each next character, rather than just picking the most likely next character.


^^^^^^^^^^^^^^^^^^^^
Response Definitions
^^^^^^^^^^^^^^^^^^^^

text:
    The protein sequence generated by the model. It is represented as a string of amino acid codes, where each letter corresponds to a different amino acid. For instance, "M" for Methionine at the beginning of each sequence.

perplexity:
    A statistical measure of how well a probability model predicts a sample. A lower perplexity score indicates a better fit between the model and the sample. In this context, it can be interpreted as a measure of the model's confidence in the generated sequence or how typical the sequence is based on the model's training data. The first sequence has a perplexity of approximately 137.23, while the second has a lower perplexity of approximately 94.08, suggesting the model is more confident in the second sequence.

----------
Related
----------

:doc:`/model-docs/protgpt2/ProtGPT2`

